@@ -1,6 +1,4 @@
-#!/usr/bin/perl
-
-use warnings;
+#!/usr/bin/perl -w
 use strict;
 use lib qw( lib );
 use Getopt::Long qw/:config posix_default no_ignore_case bundling auto_help/;
@@ -16,7 +14,6 @@ GetOptions(\my %options, qw/
     accesskey=s
     method=s
     url=s
-    path=s
     file=s
     protocol=s
     silence=i
@@ -27,9 +24,6 @@ $account = $options{ account } unless $account;
 $accesskey = $options{ accesskey } unless $accesskey;
 my $method = $options{ method };
 my $url   = $options{ url };
-if (! $url ) {
-    $url = $options{ path };
-}
 my $file  = $options{ file };
 my $protocol = $options{ protocol } || 'https';
 my $silence = $options{ silence };
@@ -51,7 +45,7 @@ if (! $accesskey ) {
 }
 
 if ( (! $account ) || (! $accesskey ) ) {
-    die
+    die 
     'Your account and primary access key of Windows Azure Blob Storage are required.';
 }
 
@@ -62,7 +56,7 @@ if (! $method ) {
 }
 
 if (! $method ) {
-    die
+    die 
     "Option '--method' is required.";
 }
 
@@ -112,4 +106,4 @@ Copyright (C) 2013, Junnama Noda.
 This program is free software;
 you can redistribute it and modify it under the same terms as Perl itself.
 
-=cut
+=cut
\ No newline at end of file
